@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## PO Files Manipulation - ~/lib/Text/PO.pm
-## Version v0.1.1
-## Copyright(c) 2018 DEGUEST Pte. Ltd.
+## Version v0.1.2
+## Copyright(c) 2021 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2018/06/21
-## Modified 2021/07/27
+## Modified 2021/07/28
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -26,7 +26,7 @@ BEGIN
     use Nice::Try;
     use Scalar::Util;
     use Text::PO::Element;
-    our $VERSION = 'v0.1.1';
+    our $VERSION = 'v0.1.2';
 };
 
 INIT
@@ -206,7 +206,7 @@ sub as_json
         }
         push( @{$hash->{elements}}, $ref );
     }
-    my $j = JSON::PP->new->relaxed;
+    my $j = JSON->new->relaxed;
     # canonical = sorting hash keys
     foreach my $t ( qw( pretty utf8 indent canonical ) )
     {
@@ -802,7 +802,7 @@ sub parse2hash
         $io->binmode( ':utf8' );
         $io->read( $buff, -s( $file ) );
         $io->close;
-        my $j = JSON::PP->new->relaxed;
+        my $j = JSON->new->relaxed;
         my $ref = {};
         try
         {
@@ -840,7 +840,7 @@ sub parse2object
         $io->binmode( ':utf8' );
         $io->read( $buff, -s( $file ) );
         $io->close;
-        my $j = JSON::PP->new->relaxed;
+        my $j = JSON->new->relaxed;
         my $ref = {};
         try
         {
@@ -1348,7 +1348,7 @@ Text::PO - Read and write PO files
 
 =head1 VERSION
 
-    v0.1.1
+    v0.1.2
 
 =head1 DESCRIPTION
 
